/* $Id: SearchIndexerDataLocationState.java 857 2010-11-10 22:56:51Z hohwille $
 * Copyright (c) The m-m-m Team, Licensed under the Apache License, Version 2.0
 * http://www.apache.org/licenses/LICENSE-2.0 */
package net.sf.mmm.search.indexer.api.state;

/**
 * This is the interface for the state of the
 * {@link net.sf.mmm.search.indexer.api.ConfiguredSearchIndexer} for a
 * particular {@link #getLocation() location}. It stores the
 * {@link #getRevision() revision} of that location if available.
 * 
 * @author Joerg Hohwiller (hohwille at users.sourceforge.net)
 * @since 1.0.0
 */
public interface SearchIndexerDataLocationState {

  /**
   * This method gets the
   * {@link net.sf.mmm.search.indexer.api.config.SearchIndexerDataLocation#getLocationUri()
   * location} this state is associated with.
   * 
   * @return the location.
   */
  String getLocation();

  /**
   * This method gets the revision of the {@link #getLocation() location} that
   * has been indexed.
   * 
   * @see net.sf.mmm.search.indexer.api.config.SearchIndexerSource#UPDATE_STRATEGY_VCS
   * @see net.sf.mmm.search.indexer.api.config.SearchIndexerDataLocation#getUpdateStrategyVariant()
   * 
   * @return the revision or <code>null</code> if no revision is set.
   */
  String getRevision();

  /**
   * This method sets the {@link #getRevision() revision}.
   * 
   * @param revision is the new revision.
   */
  void setRevision(String revision);

}
